==> hlint-3.3.1-73-x86_64.pkg.tar.zst: usr/share/haskell/register/hlint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hlint
version:              3.3.1
visibility:           public
id:                   hlint-3.3.1-BdhDjMlQPnFh6RmWUjxeU
key:                  hlint-3.3.1-BdhDjMlQPnFh6RmWUjxeU
license:              BSD-3-Clause
copyright:            Neil Mitchell 2006-2021
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:               Neil Mitchell <ndmitchell@gmail.com>
homepage:             https://github.com/ndmitchell/hlint#readme
synopsis:             Source code suggestions
description:          HLint gives suggestions on how to improve your source code.
category:             Development
abi:                  9e09f313c6903cec3feac99b63820bd0
exposed:              True
exposed-modules:      Language.Haskell.HLint
hidden-modules:
    Paths_hlint Apply CmdLine Extension Fixity HLint HsColour Idea
    Report Util Parallel Refact Timing CC EmbedData Summary
    Config.Compute Config.Haskell Config.Read Config.Type Config.Yaml
    GHC.All GHC.Util GHC.Util.ApiAnnotation GHC.Util.View
    GHC.Util.Brackets GHC.Util.DynFlags GHC.Util.FreeVars
    GHC.Util.HsDecl GHC.Util.HsExpr GHC.Util.SrcLoc GHC.Util.Scope
    GHC.Util.Unify Hint.All Hint.Bracket Hint.Comment Hint.Duplicate
    Hint.Export Hint.Extensions Hint.Fixities Hint.Import Hint.Lambda
    Hint.List Hint.ListRec Hint.Match Hint.Monad Hint.Naming
    Hint.NewType Hint.Pattern Hint.Pragma Hint.Restrict Hint.Smell
    Hint.Type Hint.Unsafe Test.All Test.Annotations Test.InputOutput
    Test.Util

import-dirs:          /usr/lib/ghc-9.0.2/site-local/hlint-3.3.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/hlint-3.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hlint
hs-libraries:         HShlint-3.3.1-BdhDjMlQPnFh6RmWUjxeU
depends:
    aeson-1.5.6.0-IOJcrOKAazg2fbKFkmU9ms
    ansi-terminal-0.11.1-3bF8hvpb5rt8AmpxYz60ww base-4.15.1.0
    bytestring-0.10.12.1 cmdargs-0.10.21-5dEStss8OK87s5amCxsPTV
    containers-0.6.4.1 cpphs-1.20.9.1-1jAFiSyqcHj3RbgQIQP02q
    data-default-0.7.1.1-EcFn1KqENcc3dlLa7FIl7R directory-1.3.6.2
    extra-1.7.10-1H2akLcBxLZHwFpL1jX6c5
    file-embed-0.0.14.0-4xxXjmkgCiV6v8HpAsLJeu filepath-1.4.2.1
    filepattern-0.1.2-Afxvp0BbDOR5ARtgCNcAqJ ghc-9.0.2 ghc-boot-9.0.2
    ghc-boot-th-9.0.2 ghc-lib-parser-ex-9.0.0.4-Aje9nuffUZQ9A6aNyK8Ae4
    hscolour-1.24.4-HKLiWvLsNQhKZwI7FyBmaY process-1.6.13.2
    refact-0.3.0.2-E230LaAGTbX8k1SiA4DqrW text-1.2.5.0
    transformers-0.5.6.2 uniplate-1.6.13-FcLX0i3NhhzJzjfx4TSAEV
    unordered-containers-0.2.16.0-GOdhS5VVGhuDfpf9ntzlf6
    utf8-string-1.0.2-9eFA57BgKXNHtjvfuIOq9f
    vector-0.12.3.1-LmWX58b6mp7Hut6wPuFfXF
    yaml-0.11.8.0-G6uUxKoUd4x6eO6RkJzxGD

haddock-interfaces:   /usr/share/doc/hlint/html/hlint.haddock
haddock-html:         /usr/share/doc/hlint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hlint-3.3.2-1-x86_64.pkg.tar.zst: usr/share/haskell/register/hlint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hlint
version:              3.3.2
visibility:           public
id:                   hlint-3.3.2-6re1wk9fka6CHXW9siJ4Pa
key:                  hlint-3.3.2-6re1wk9fka6CHXW9siJ4Pa
license:              BSD-3-Clause
copyright:            Neil Mitchell 2006-2021
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:               Neil Mitchell <ndmitchell@gmail.com>
homepage:             https://github.com/ndmitchell/hlint#readme
synopsis:             Source code suggestions
description:          HLint gives suggestions on how to improve your source code.
category:             Development
abi:                  605fdf27b633ae222bf813da9cc26ecc
exposed:              True
exposed-modules:      Language.Haskell.HLint
hidden-modules:
    Paths_hlint Apply CmdLine Extension Fixity HLint HsColour Idea
    Report Util Parallel Refact Timing CC EmbedData Summary
    Config.Compute Config.Haskell Config.Read Config.Type Config.Yaml
    GHC.All GHC.Util GHC.Util.ApiAnnotation GHC.Util.View
    GHC.Util.Brackets GHC.Util.DynFlags GHC.Util.FreeVars
    GHC.Util.HsDecl GHC.Util.HsExpr GHC.Util.SrcLoc GHC.Util.Scope
    GHC.Util.Unify Hint.All Hint.Bracket Hint.Comment Hint.Duplicate
    Hint.Export Hint.Extensions Hint.Fixities Hint.Import Hint.Lambda
    Hint.List Hint.ListRec Hint.Match Hint.Monad Hint.Naming
    Hint.NewType Hint.Pattern Hint.Pragma Hint.Restrict Hint.Smell
    Hint.Type Hint.Unsafe Test.All Test.Annotations Test.InputOutput
    Test.Util

import-dirs:          /usr/lib/ghc-9.0.2/site-local/hlint-3.3.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/hlint-3.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hlint
hs-libraries:         HShlint-3.3.2-6re1wk9fka6CHXW9siJ4Pa
depends:
    aeson-1.5.6.0-AIOjF99b4i15RTiIgKIYjO
    ansi-terminal-0.11.1-HNnEdSu65ZhDbOYiPbejEK base-4.15.1.0
    bytestring-0.10.12.1 cmdargs-0.10.21-5dEStss8OK87s5amCxsPTV
    containers-0.6.4.1 cpphs-1.20.9.1-1jAFiSyqcHj3RbgQIQP02q
    data-default-0.7.1.1-EcFn1KqENcc3dlLa7FIl7R directory-1.3.6.2
    extra-1.7.10-FwjYOjfFUdjBsZWzTyDNI7
    file-embed-0.0.15.0-FF5xUPWKaB3GI64c6hgPnn filepath-1.4.2.1
    filepattern-0.1.2-9cTjOz9RKwG1n3EYJuRcCp ghc-9.0.2 ghc-boot-9.0.2
    ghc-boot-th-9.0.2 ghc-lib-parser-ex-9.0.0.4-4GVZIdhzRJPE8Su8uFV0Ny
    hscolour-1.24.4-HKLiWvLsNQhKZwI7FyBmaY process-1.6.13.2
    refact-0.3.0.2-E230LaAGTbX8k1SiA4DqrW text-1.2.5.0
    transformers-0.5.6.2 uniplate-1.6.13-2DHszLKDCnZIrssB1Zkopx
    unordered-containers-0.2.17.0-3BdVQ0XjWEwL87G4XZjXWP
    utf8-string-1.0.2-9eFA57BgKXNHtjvfuIOq9f
    vector-0.12.3.1-5HK1DqtCbep8rMk53O5plV
    yaml-0.11.8.0-E2g30QdRHu22pNXhvNbFUA

haddock-interfaces:   /usr/share/doc/hlint/html/hlint.haddock
haddock-html:         /usr/share/doc/hlint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
